### `>>> import replit`

![compute](https://github.com/kennethreitz42/replit-py/blob/kr-cleanup/ext/readme.gif?raw=true)

This repository is the home for the `replit` Python package, which provides:

- A fully-featured database client for [Replit DB](https://docs.repl.it/misc/database).
- A Flask–based application framework for accelerating development on the platform.
- Replit user profile metadata retrieval (more coming here!).
- A simple audio library that can play tones and audio files!

### Open Source License

This library is licensed under the [ISC License](https://en.wikipedia.org/wiki/ISC_license) and is free for you to use, change, or even profit from!
